"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocationTracker = exports.setCurrentLocationTracker = exports.getCurrentLocationTracker = void 0;
let currentLocationTracker;
function getCurrentLocationTracker() {
    return currentLocationTracker;
}
exports.getCurrentLocationTracker = getCurrentLocationTracker;
function setCurrentLocationTracker(tracker) {
    currentLocationTracker = tracker;
}
exports.setCurrentLocationTracker = setCurrentLocationTracker;
class LocationTracker {
    source;
    parser;
    lastPosition;
    lastIndex;
    constructor(source, parser) {
        this.source = source;
        this.parser = parser;
        this.lastPosition = {
            line: 1,
            column: 1
        };
        this.lastIndex = 0;
    }
    getCurrentStartPosition() {
        return this.getPosition(this.parser.startIndex);
    }
    getCurrentEndPosition() {
        return this.getPosition(this.parser.endIndex);
    }
    getPosition(index) {
        if (index < this.lastIndex) {
            throw new Error('Source indices must be monotonic');
        }
        while (this.lastIndex < index) {
            if (this.source.charCodeAt(this.lastIndex) === /* \n */ 10) {
                this.lastPosition.line++;
                this.lastPosition.column = 1;
            }
            else {
                this.lastPosition.column++;
            }
            this.lastIndex++;
        }
        return {
            line: this.lastPosition.line,
            column: this.lastPosition.column
        };
    }
}
exports.LocationTracker = LocationTracker;
//# sourceMappingURL=location-tracker.js.map